This introduces LipoProteinLipase (lpl), a simple tool for creating fat binaries. It represents a direct replacement of the creaky hccgenco.sh script, which had various issues. The format it uses is that of a code object bundle, generated by the Clang Offload Bundler. The output is always suffixed with the ".adipose" extension. It is shared with HCC. The hipcc script and associated tests are modified to use lpl. Help can be obtained by invoking lpl --help. A more computer-sciency / corporate friendly name is likely to be beneficial, which is a reason for choosing easily searchable/replaceable names such as lpl or adipose.

[ROCm/hip commit: b842394957]
このコミットが含まれているのは:
Alex Voicu
2017-12-08 04:22:57 +00:00
コミット 56fd7f129a
17個のファイルの変更3958行の追加94行の削除
+1 -1
ファイルの表示
@@ -22,7 +22,7 @@ THE SOFTWARE.
#include "hip/hip_runtime.h"
extern "C" __global__ void hello_world(hipLaunchParm lp, float *a, float *b)
extern "C" __global__ void hello_world(float *a, float *b)
{
int tx = hipThreadIdx_x;
b[tx] = a[tx];